package com.jianshui.system.mapper;

import java.util.List;

import com.jianshui.common.core.domain.entity.Companyservice;

/**
 * 销方信息Mapper接口
 *
 * @author jianshui
 * @date 2021-12-21
 */
public interface CompanyserviceMapper {
    /**
     * 查询销方信息
     *
     * @param companyid 销方信息主键
     * @return 销方信息
     */
    public Companyservice selectCompanyserviceByCompanyid(Long companyid);

    /**
     * 根据销方信息取第一个sellertax
     *
     * @param sellertax
     * @return
     */
    public Companyservice selectFirstCompanyserviceBySellerTax(String sellertax);

    /**
     * 根据identity获取销方信息
     *
     * @param Identity
     * @return
     */
    public Companyservice selectCompanyserviceByIdentity(String Identity);


    public Companyservice selectCompanyserviceByTaxcode(String taxcode);

    /**
     * 查询销方信息列表
     *
     * @param companyservice 销方信息
     * @return 销方信息集合
     */
    public List<Companyservice> selectCompanyserviceList(Companyservice companyservice);

    /**
     * 新增销方信息
     *
     * @param companyservice 销方信息
     * @return 结果
     */
    public int insertCompanyservice(Companyservice companyservice);

    /**
     * 修改销方信息
     *
     * @param companyservice 销方信息
     * @return 结果
     */
    public int updateCompanyservice(Companyservice companyservice);

    /**
     * 删除销方信息
     *
     * @param companyid 销方信息主键
     * @return 结果
     */
    public int deleteCompanyserviceByCompanyid(Long companyid);

    /**
     * 批量删除销方信息
     *
     * @param companyids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCompanyserviceByCompanyids(Long[] companyids);
}
